%global prerel_tag rc92

%global provider github
%global provider_tld com
%global project opencontainers
%global repo runc
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}


%global provider github
%global provider_tld com
%global project opencontainers
%global repo runc
# https://github.com/opencontainers/runc
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path %{provider_prefix}
%global git0 https://github.com/opencontainers/runc
%global commit0 ff819c7e9184c13b7c2607fe6c30ae19403a7aff
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})

#debuginfo not supported with Go
%global gopath  %{_libdir}/golang
%define gosrc %{gopath}/src/pkg/%{import_path}

Name:           %{project}-%{repo}
Epoch:          1
Version:        1.0.0
Release:        %mkrel 0.%{prerel_tag}.7.dev.git%{shortcommit0}
#Release:        %mkrel %{?prerel_tag:0.%{prerel_tag}.}5
Summary:        runc container cli tools
License:        ASL 2.0
Group:          System/Configuration

URL:            https://www.opencontainers.org/
#Source0:       %{git0}/archive/v%{version}%{?prerel_tag:-%{prerel_tag}}/%{repo}-%{version}%{?prerel_tag:-%{prerel_tag}}.tar.gz
Source0: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz


# Allow runc and podman to work with sd_notify
# From: https://github.com/opencontainers/runc/pull/1807
#Patch0101:      opencontainers-runc-PR1807.patch

BuildRequires:  gcc
BuildRequires:  glibc-static-devel
BuildRequires:  pkgconfig(libseccomp)

# ensure build uses golang 1.13 or above
BuildRequires:  golang >= 1.13

%description
runc is a CLI tool for spawning and running containers according to the OCI specification.


%prep
#autosetup -n %{repo}-%{version}%{?prerel_tag:-%{prerel_tag}} -p1
%autosetup -n %{repo}-%{commit0} -p1

%build
export GOPATH=$(pwd)/Godeps/_workspace:%{gopath}
export GIT_BRANCH=v%{version}-%{prerel_tag}
export COMMIT_NO=%{commit0}
export COMMIT=%{commit0}
# for rc3 use this build sequence:
ln -sf $(pwd)/vendor $(pwd)/src
mkdir -p $(pwd)/vendor/github.com/opencontainers/runc
cp -a libcontainer $(pwd)/vendor/github.com/opencontainers/runc
cp -a types $(pwd)/vendor/github.com/opencontainers/runc
export GOPATH=$(pwd):%{gopath}
rm -f go.mod
export GO111MODULE=off
make BUILDTAGS="seccomp selinux"

%install
# install binary
install -d %{buildroot}%{_bindir}
install -p -m 755 runc %{buildroot}%{_bindir}
cd %{buildroot}%{_bindir}
for i in *; do
	ln -sf $i docker-$i
done

%files
%doc CONTRIBUTING.md MAINTAINERS* PRINCIPLES.md README.md
%license LICENSE NOTICE
%{_bindir}/*


%changelog
* Sun Nov 01 2020 bcornec <bcornec> 1:1.0.0-0.rc92.7.dev.gitff819c7.mga8
+ Revision: 1641125
- update to upstream opencontainer runc 1.0.0 rc92

* Sat Apr 11 2020 joequant <joequant> 1:1.0.0-0.rc10.7.dev.gitccbb336.mga8
+ Revision: 1566291
- add libseccomp to buildrequires
- update to latest git revision
- fix typo
- add selinux and seccomp tags

* Sun Feb 23 2020 bcornec <bcornec> 1:1.0.0-0.rc10.4.mga8
+ Revision: 1549504
- Update to runc-1.0.0-rc10 to fix mga#26173

* Wed Feb 19 2020 umeabot <umeabot> 1:1.0.0-0.rc9.4.mga8
+ Revision: 1543454
- Mageia 8 Mass Rebuild

* Mon Jan 20 2020 bcornec <bcornec> 1:1.0.0-0.rc9.3.mga8
+ Revision: 1481637
- Update opencontainers-runc to upstream 1.0rc9 to fix CVE-2019-16884

* Wed Sep 04 2019 bcornec <bcornec> 1:1.0.0-0.rc8.3.mga8
+ Revision: 1437233
- update to upstream v1.0.0rc8 opencontainers-runc

* Tue Feb 12 2019 luigiwalser <luigiwalser> 1:1.0.0-0.rc6.3.mga7
+ Revision: 1365382
- add upstream patch to fix CVE-2019-5736

* Sat Feb 02 2019 luigiwalser <luigiwalser> 1:1.0.0-0.rc6.2.mga7
+ Revision: 1362659
- add upstream pull request 1962 to fix security issue (mga#25253, rhbz#1663068)

* Sun Jan 20 2019 ngompa <ngompa> 1:1.0.0-0.rc6.1.mga7
+ Revision: 1358469
- Upgrade to runc-1.0.0-rc6
- Add Epoch to fix broken version scheme
- Add patch from Fedora to allow sd_notify to work with runc and podman

* Tue Oct 16 2018 bcornec <bcornec> 1.0.0rc5-3.mga7
+ Revision: 1320896
- SILIENT: update sha1
- update to upstream 1.0.0rc5 opencontainers-runc

* Sun Sep 23 2018 umeabot <umeabot> 1.0.0rc2-3.mga7
+ Revision: 1299988
- Mageia 7 Mass Rebuild

* Sun May 28 2017 akien <akien> 1.0.0rc2-2.mga6
+ Revision: 1105408
- Rebuild against fixed golang
+ bcornec <bcornec>
- Go back to rc2 build procedure for opencontainers-runc
- go back to rc2 of opencontainers-runc as rc3 doesn't work with docker 17.03
- update to upstream 1.0.0rc3

* Thu Nov 24 2016 bcornec <bcornec> 1.0.0rc2-1.mga6
+ Revision: 1069706
- update to upstream 1.0.0rc2

* Sat Sep 24 2016 bcornec <bcornec> 1.0.0rc1-1.mga6
+ Revision: 1055669
- Update to upstream 1.0.rc1 needed by docker 0.12.1

* Mon May 23 2016 bcornec <bcornec> 0.1.1-2.mga6
+ Revision: 1018001
- remove restriction on arch

* Sun May 22 2016 bcornec <bcornec> 0.1.1-1.mga6
+ Revision: 1017692
- Create an opencontainers-runc package needed by docker >= 1.11
- Created package structure for opencontainers-runc.

